schema

package
v0.0.0-...-ec4ef83 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 15, 2025 License: MIT Imports: 13 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GraphMapToProto

func GraphMapToProto(data map[string]interface{}) (*gripql.Graph, error)

func GraphToJSONString

func GraphToJSONString(graph *gripql.Graph) (string, error)

GraphToJSONString returns a graph formatted as a JSON string

func GraphToYAMLString

func GraphToYAMLString(graph *gripql.Graph) (string, error)

GraphToYAMLString returns a graph formatted as a YAML string

func ParseJSONGraphs

func ParseJSONGraphs(raw []byte) ([]*gripql.Graph, error)

ParseJSONGraph parses a JSON doc into the given Graph instance.

func ParseJSONGraphsFile

func ParseJSONGraphsFile(relpath string) ([]*gripql.Graph, error)

ParseJSONGraphFile parses a graph file, which is formatted in JSON, and returns a slice of graph objects.

func ParseJSchema

func ParseJSchema(bytes []byte, graphName string) ([]*gripql.Graph, error)

func ParseJsonSchema

func ParseJsonSchema(relpath string, graphName string) ([]*gripql.Graph, error)

func ParseYAMLGraph

func ParseYAMLGraph(raw []byte) (*gripql.Graph, error)

ParseYAMLGraph parses a YAML doc into the given Graph instance.

func ParseYAMLGraphPath

func ParseYAMLGraphPath(relpath string) (*gripql.Graph, error)

func ParseYAMLGraphs

func ParseYAMLGraphs(raw []byte) ([]*gripql.Graph, error)

ParseYAMLGraph parses a YAML doc into the given Graph instance.

func ParseYAMLGraphsFile

func ParseYAMLGraphsFile(relpath string) ([]*gripql.Graph, error)

ParseYAMLGraphFile parses a graph file, which is formatted in YAML, and returns a slice of graph objects.

func ParseYAMLSchemaGraphs

func ParseYAMLSchemaGraphs(source []byte, graphName string) ([]*gripql.Graph, error)

func ParseYSchemaToVertex

func ParseYSchemaToVertex(bytes []byte) (map[string]any, error)

func ParseYamlSchemaPath

func ParseYamlSchemaPath(relpath string, graphName string) ([]*gripql.Graph, error)

func ScanSchema

func ScanSchema(conn gripql.Client, graph string, sampleCount uint32, exclude []string) (*gripql.Graph, error)

ScanSchema attempts to construct a schema of a graph by sampling vertices and edges This version of the schema scanner (vs the ones found in the drivers) can be run via the client library

Types

This section is empty.

Jump to