Documentation
¶
Index ¶
- func GraphMapToProto(data map[string]interface{}) (*gripql.Graph, error)
- func GraphToJSONString(graph *gripql.Graph) (string, error)
- func GraphToYAMLString(graph *gripql.Graph) (string, error)
- func ParseJSONGraphs(raw []byte) ([]*gripql.Graph, error)
- func ParseJSONGraphsFile(relpath string) ([]*gripql.Graph, error)
- func ParseJSchema(bytes []byte, graphName string) ([]*gripql.Graph, error)
- func ParseJsonSchema(relpath string, graphName string) ([]*gripql.Graph, error)
- func ParseYAMLGraph(raw []byte) (*gripql.Graph, error)
- func ParseYAMLGraphPath(relpath string) (*gripql.Graph, error)
- func ParseYAMLGraphs(raw []byte) ([]*gripql.Graph, error)
- func ParseYAMLGraphsFile(relpath string) ([]*gripql.Graph, error)
- func ParseYAMLSchemaGraphs(source []byte, graphName string) ([]*gripql.Graph, error)
- func ParseYSchemaToVertex(bytes []byte) (map[string]any, error)
- func ParseYamlSchemaPath(relpath string, graphName string) ([]*gripql.Graph, error)
- func ScanSchema(conn gripql.Client, graph string, sampleCount uint32, exclude []string) (*gripql.Graph, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GraphToJSONString ¶
GraphToJSONString returns a graph formatted as a JSON string
func GraphToYAMLString ¶
GraphToYAMLString returns a graph formatted as a YAML string
func ParseJSONGraphs ¶
ParseJSONGraph parses a JSON doc into the given Graph instance.
func ParseJSONGraphsFile ¶
ParseJSONGraphFile parses a graph file, which is formatted in JSON, and returns a slice of graph objects.
func ParseJsonSchema ¶
func ParseYAMLGraph ¶
ParseYAMLGraph parses a YAML doc into the given Graph instance.
func ParseYAMLGraphs ¶
ParseYAMLGraph parses a YAML doc into the given Graph instance.
func ParseYAMLGraphsFile ¶
ParseYAMLGraphFile parses a graph file, which is formatted in YAML, and returns a slice of graph objects.
func ParseYAMLSchemaGraphs ¶
func ParseYamlSchemaPath ¶
func ScanSchema ¶
func ScanSchema(conn gripql.Client, graph string, sampleCount uint32, exclude []string) (*gripql.Graph, error)
ScanSchema attempts to construct a schema of a graph by sampling vertices and edges This version of the schema scanner (vs the ones found in the drivers) can be run via the client library
Types ¶
This section is empty.